@@ -504,6 +504,8 @@ gedit_app_startup (GApplication *application)
 	                                 "<Primary><Shift>L", "win.save-all", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>T", "win.new-tab", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>T", "win.reopen-closed-tab", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>W", "win.close", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
@@ -1680,7 +1682,7 @@ _gedit_app_extend_menu (GeditApp    *app,
 		}
 	}
 
-	return section != NULL ? _gedit_menu_extension_new (G_MENU (section)) : NULL;
+	return section != NULL ? gedit_menu_extension_new (G_MENU (section)) : NULL;
 }
 
 /* ex:set ts=8 noet: */
