@@ -45,6 +45,7 @@ struct _GeditWindowPrivate
 	GeditMultiNotebook *multi_notebook;
 
 	GtkWidget      *side_panel;
+	GtkWidget      *side_stack_switcher;
 	GtkWidget      *bottom_panel_box;
 	GtkWidget      *bottom_panel;
 
@@ -105,6 +106,8 @@ struct _GeditWindowPrivate
 
 	gchar          *direct_save_uri;
 
+	GSList         *closed_docs_stack;
+
 #ifdef OS_OSX
 	GtkOSXApplicationMenuGroup *mac_menu_group;
 #endif
